from django.core.mail import send_mail
from django.contrib.comments.signals import comment_was_posted
from django.utils.translation import ugettext as _
from django.db.models.signals import post_save

from jumbo.utils.functions import get_settings
from jumbo.core.urlresolvers import reverse
from jumbo.shortcuts import render_to_string

from ticket.email import TicketEmail
from ticket.models import TicketProject
from procedure.models import ProcedureRow 

class CommentEmail(TicketEmail):
    def __init__(self, ticket, comment):
        self.obj = ticket
        self.subject_msg = "%s[COMMENTO] Ticket %s" % (get_settings("ticket.settings", "TICKET_SUBJECT_PREFIX"),ticket.id)
        if ticket.project:
            self.subject_msg = "%s[#%s][COMMENTO] Ticket %s - Progetto : %s" % (get_settings("ticket.settings", "TICKET_SUBJECT_PREFIX"), ticket.project.id, ticket.id, ticket.project)
        else:
            self.subject_msg += " - Progetto Generico"

        self.recipient_list = ticket.get_all_address_to_send_email()
        self.body_msg = self.html_body_msg = render_to_string("ticket/email/new_comment.html",
                                                               ticket=ticket,
                                                               comment=comment,
                                                            )
        self.from_mail = ticket.get_from_mail()


def send_comment_email(sender, comment, request, **kwargs):
    send_mail = get_settings("ticket.settings", "SEND_MAIL")
    if send_mail:
        ct = comment.content_type
        app_name = ct.name

        if app_name != 'Ticket':
            return

        ticket = ct.model_class().objects.get(pk=comment.object_pk)
        comment_email = CommentEmail(ticket, comment)
        comment_email.send()
comment_was_posted.connect(send_comment_email)